# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class DataManagerTaskSerializerPredictionsItem(UniversalBaseModel):
    result: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = None
    score: typing.Optional[float] = None
    model_version: typing.Optional[str] = None
    model: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    model_run: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    task: typing.Optional[int] = None
    project: typing.Optional[float] = None
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
