# This file was auto-generated by Fern from our API Definition.

import typing

PromptVersionProvider = typing.Union[
    typing.Literal["OpenAI", "AzureOpenAI", "AzureAIFoundry", "VertexAI", "Gemini", "Anthropic", "Custom"], typing.Any
]
