# This file was auto-generated by Fern from our API Definition.

import typing

ExportFormat = typing.Union[
    typing.Literal[
        "JSON",
        "JSON_MIN",
        "CSV",
        "TSV",
        "CONLL2003",
        "COCO",
        "VOC",
        "BRUSH_TO_NUMPY",
        "BRUSH_TO_PNG",
        "ASR_MANIFEST",
        "YOLO",
        "YOLO_OBB",
        "CSV_OLD",
        "YOLO_WITH_IMAGES",
        "COCO_WITH_IMAGES",
        "YOLO_OBB_WITH_IMAGES",
    ],
    typing.Any,
]
