# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .pause_paused_by import PausePausedBy
import pydantic
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class Pause(UniversalBaseModel):
    id: typing.Optional[int] = None
    project: typing.Optional[int] = None
    user: typing.Optional[int] = None
    paused_by: typing.Optional[PausePausedBy] = pydantic.Field(default=None)
    """
    User who created the pause
    """

    reason: str
    verbose_reason: typing.Optional[str] = None
    deleted_by: typing.Optional[int] = None
    deleted_at: typing.Optional[dt.datetime] = None
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
