# This file was auto-generated by Fern from our API Definition.

import typing

InferenceRunStatus = typing.Union[
    typing.Literal["Pending", "InProgress", "Completed", "Failed", "Canceled"], typing.Any
]
