# This file was auto-generated by Fern from our API Definition.

import typing
from .prompt_associated_projects_item_id import PromptAssociatedProjectsItemId

PromptAssociatedProjectsItem = typing.Union[int, PromptAssociatedProjectsItemId]
